@@ -4,14 +4,13 @@ use warnings;
 use utf8;
 
 package Dist::Zilla::Plugin::Author::KENTNL::MinimumPerl;
-BEGIN {
-  $Dist::Zilla::Plugin::Author::KENTNL::MinimumPerl::AUTHORITY = 'cpan:KENTNL';
-}
-$Dist::Zilla::Plugin::Author::KENTNL::MinimumPerl::VERSION = '2.008001';
+$Dist::Zilla::Plugin::Author::KENTNL::MinimumPerl::VERSION = '2.009000';
 # FILENAME: MinimumPerl.pm
 # CREATED: 31/10/11 05:25:54 by Kent Fredric (kentnl) <kentfredric@gmail.com>
 # ABSTRACT: The MinimumPerl Plugin with a few hacks
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
 
 
 
@@ -150,7 +149,7 @@ Dist::Zilla::Plugin::Author::KENTNL::MinimumPerl - The MinimumPerl Plugin with a
 
 =head1 VERSION
 
-version 2.008001
+version 2.009000
 
 =head1 METHODS
 
